@@ -1,3 +1,4 @@
+# coding=utf-8
 # --------------------------------------------------------------------------------------------
 # Copyright (c) Microsoft Corporation. All rights reserved.
 # Licensed under the MIT License. See License.txt in the project root for license information.
@@ -174,12 +175,12 @@ helps['sql db export'] = """
             az sql db export -s myserver -n mydatabase -g mygroup -p password -u login \\
                 --storage-key "?sr=b&sp=rw&se=2018-01-01T00%3A00%3A00Z&sig=mysignature&sv=2015-07-08" \\
                 --storage-key-type SharedAccessKey \\
-                --storage-uri https://mystorageaccount.blob.core.windows.net/bacpacs/mybacpac.bacpac
+                --storage-uri https://mystorageaccount.blob.core.windows.net/bacpacs/myBacpac.bacpac
         - name: Export bacpac using a storage account key.
           text: |
             az sql db export -s myserver -n mydatabase -g mygroup -p password -u login \\
                 --storage-key MYKEY== --storage-key-type StorageAccessKey \\
-                --storage-uri https://mystorageaccount.blob.core.windows.net/bacpacs/mybacpac.bacpac
+                --storage-uri https://mystorageaccount.blob.core.windows.net/bacpacs/myBacpac.bacpac
     """
 helps['sql db import'] = """
     type: command
@@ -194,12 +195,12 @@ helps['sql db import'] = """
             az sql db import -s myserver -n mydatabase -g mygroup -p password -u login \\
                 --storage-key "?sr=b&sp=rw&se=2018-01-01T00%3A00%3A00Z&sig=mysignature&sv=2015-07-08" \\
                 --storage-key-type SharedAccessKey \\
-                --storage-uri https://mystorageaccount.blob.core.windows.net/bacpacs/mybacpac.bacpac
+                --storage-uri https://mystorageaccount.blob.core.windows.net/bacpacs/myBacpac.bacpac
         - name: Import bacpac into an existing database using a storage account key.
           text: |
             az sql db import -s myserver -n mydatabase -g mygroup -p password -u login --storage-key MYKEY== \\
                 --storage-key-type StorageAccessKey \\
-                --storage-uri https://mystorageaccount.blob.core.windows.net/bacpacs/mybacpac.bacpac
+                --storage-uri https://mystorageaccount.blob.core.windows.net/bacpacs/myBacpac.bacpac
     """
 helps['sql db restore'] = """
     type: command
@@ -321,6 +322,22 @@ helps['sql elastic-pool op cancel'] = """
         - name: Cancel an operation.
           text: az sql elastic-pool op cancel -g mygroup -s myserver -ep myelasticpool -n d2896db1-2ba8-4c84-bac1-387c430cce40
     """
+helps['sql failover-group'] = """
+    type: group
+    short-summary: Manage SQL Failover Groups.
+    """
+helps['sql failover-group create'] = """
+    type: command
+    short-summary: Creates a failover group.
+    """
+helps['sql failover-group update'] = """
+    type: command
+    short-summary: Updates the failover group.
+    """
+helps['sql failover-group set-primary'] = """
+    type: command
+    short-summary: Set the primary of the failover group by failing over all databases from the current primary server.
+    """
 helps['sql server'] = """
     type: group
     short-summary: Manage SQL servers.
@@ -328,6 +345,9 @@ helps['sql server'] = """
 helps['sql server create'] = """
     type: command
     short-summary: Create a server.
+    examples:
+        - name: Create a server.
+          text: az sql server create -l westus -g mygroup -n myserver -u myadminuser -p myadminpassword
     """
 helps['sql server list'] = """
     type: command
@@ -369,18 +389,35 @@ helps['sql server firewall-rule'] = """
 helps['sql server firewall-rule create'] = """
     type: command
     short-summary: Create a firewall rule.
+    examples:
+        - name: Create a firewall rule
+          text: az sql server firewall-rule create -g mygroup -s myserver -n myrule
+                --start-ip-address 1.2.3.4 --end-ip-address 5.6.7.8
+        - name: Create a firewall rule that allows access from Azure services
+          text: az sql server firewall-rule create -g mygroup -s myserver -n myrule
+                --start-ip-address 0.0.0.0 --end-ip-address 0.0.0.0
     """
 helps['sql server firewall-rule update'] = """
     type: command
     short-summary: Update a firewall rule.
+    examples:
+        - name: Update a firewall rule
+          text: az sql server firewall-rule update -g mygroup -s myserver -n myrule
+                --start-ip-address 9.8.7.6 --end-ip-address 5.4.3.2
     """
 helps['sql server firewall-rule show'] = """
     type: command
     short-summary: Shows the details for a firewall rule.
+    examples:
+        - name: Show a firewall rule
+          text: az sql server firewall-rule show -g mygroup -s myserver -n myrule
     """
 helps['sql server firewall-rule list'] = """
     type: command
     short-summary: List a server's firewall rules.
+    examples:
+        - name: List a server's firewall rules
+          text: az sql server firewall-rule list -g mygroup -s myserver
     """
 helps['sql server key'] = """
     type: group
